
import pygame
from pygame.locals import *

import qgl
import qgle

def basic_screen(size):
    """
    Returns a root node with viewport and world children.
    """
    root_node = qgl.scene.Root()
    root_node.add(
        qgl.scene.PerspectiveViewport(
            qgl.scene.World()
        )
    )
    viewport = root_node[0]
    world = viewport[0]
    world.environment = qgl.scene.Group()
    world.add(world.environment)
    viewport.screen_dimensions = (0,0,size[0], size[1])
    viewport.aspect = float(size[0]) / size[1]
    return root_node, viewport, world

def main():
    pygame.init()
    flags =  OPENGL|DOUBLEBUF|HWSURFACE
    pygame.display.set_mode((800,600), flags)
    
    compiler = qgl.render.Compiler()
    render = qgl.render.Render()
    picker = qgl.render.Picker()
    
    clock = pygame.time.Clock()
    
    root_node, viewport, world = basic_screen((800,600))
    
    texture = qgl.scene.Texture("data/r4cruiser.jpg", filter=True, mipmap=True)
    mesh = qgl.scene.Mesh("data/r4cruiser.obj")
    model = qgl.scene.Group(texture,mesh)
    light = qgl.scene.Light(position=(0,0,10), ambient=(0.7,0.7,0.7,0.7))
    
    world.environment.add(light)
    world.environment.add(model)
    world.environment.add(qgl.scene.Fog(start=20, end=80))
    quad = qgl.scene.Quad((120,80))
    quad.texture_coords=((0.0,0.0),(0.0,2.0),(2.0,2.0),(2.0,0.0))
    
    background = qgl.scene.Group(qgl.scene.Color((0.5,0.5,0.5,0.3)), qgl.scene.Texture('data/bg.jpg',filter=True,mipmap=True), quad)
    background.update(translate=(0,0,-50),)
    
    quad = qgl.scene.Quad((9,2))
    logo_color = qgl.scene.Color((1.0,1.0,1.0,0.0))
    logo = qgl.scene.Group(logo_color, qgl.scene.Texture('data/ec.png',filter=True,mipmap=True), quad)
    
    world.foreground.add(qgl.scene.DepthTest(False), logo)
    #world.background.add(qgl.scene.DepthTest(False), background)
    
    model.update(axis=(0,1,0), angle=180, translate=(-5,5,-120), velocity=(0.0,0.0,0.1,0.0))
    
    fighter1 = qgl.scene.Group(qgl.scene.Texture('data/r4fighter.jpg'), qgl.scene.Mesh('data/r4fighter.obj'))
    fighter1.update(translate=(-5,-7,0), velocity=(0.0,0.0,-0.5,0.0))
    fighter2 = qgl.scene.Group(qgl.scene.Texture('data/r4fighter.jpg'), qgl.scene.Mesh('data/r4fighter.obj'))
    fighter2.update(translate=(-3,-4,10), velocity=(0.0,0.0,-0.5,0.0))
    fighter3 = qgl.scene.Group(qgl.scene.Texture('data/r4fighter.jpg'), qgl.scene.Mesh('data/r4fighter.obj'))
    fighter3.update(translate=(-7,-4,5), velocity=(0.0,0.0,-0.5,0.0))
    
    
    
    model.add(fighter1, fighter2, fighter3)
    root_node.accept(compiler)
    
    speed = [1.0]
    
    
    
    def switch_light():
        if light in world.environment.leaves:
            world.environment.remove(light)
        else:
            world.environment.add(light)
            
        print world.environment
        
    while True:
        for event in pygame.event.get():
            if event.type is QUIT:
                return
            elif event.type is KEYDOWN:
                if event.key == 27: 
                    print clock.get_fps()
                    return
                
                if event.unicode == 'l':
                    switch_light()
                    
            elif event.type is MOUSEBUTTONDOWN:
                
                if event.button == 4: #SCROLL UP
                    move_in()
                elif event.button == 5: #SCROLL DOWN
                    move_out()
                else:
                    pass
                
        r,g,b,a = logo_color.rgba
        a += 0.01
        logo_color.rgba = r,g,b,a
        qgle.drive(root_node)
        root_node.accept(render)
        clock.tick(30)
        pygame.display.flip()
        
        
main()
