
import pygame
from pygame.locals import *

import qgl
import qgl.shaders
from glew import *

def basic_screen(size):
    """
    Returns a root node with viewport and world children.
    """
    root_node = qgl.scene.Root()
    root_node.add(
        qgl.scene.PerspectiveViewport(
            qgl.scene.World()
        )
    )
    viewport = root_node[0]
    world = viewport[0]
    viewport.screen_dimensions = (0,0,size[0], size[1])
    viewport.aspect = float(size[0]) / size[1]
    return root_node, viewport, world


def main():
    pygame.init()
    flags =  OPENGL|DOUBLEBUF|HWSURFACE
    pygame.display.set_mode((800,600), flags)
    compiler = qgl.render.Compiler()
    render = qgl.render.Render()
    picker = qgl.render.Picker()
    
    clock = pygame.time.Clock()
    
    root_node, viewport, world = basic_screen((800,600))
    root_node.background_color = (1,1,0,1)
    vertex_shader = """
uniform float time;

void main(void) {
    vec4 v = vec4(gl_Vertex);
    v.z = sin(5.0*v.x + time*0.01)*0.25;
    gl_Position = gl_ModelViewProjectionMatrix * v;
} 
"""

    fragment_shader = """
void main() {
    gl_FragColor = vec4(0.4,0.4,0.8,1.0);
}
"""
    model = qgl.scene.Group(qgl.scene.Mesh("test.obj"))
    prog = qgl.shaders.Program(vertex_shader, fragment_shader)
    world.foreground.add(prog)
    world.foreground.add(model)
    world.foreground.axis = (0,1,0)
    world.foreground.angle = 90
    root_node.accept(compiler)
    time  = 1.0
    
    while True:
        for event in pygame.event.get():
            if event.type is QUIT:
                return
            elif event.type is KEYDOWN:
                print clock.get_fps()
                if event.key == 27: 
                    return
            elif event.type is MOUSEBUTTONDOWN:
                picker.set_position(event.pos)
                root_node.accept(picker)
                for hit in  picker.hits:
                    hit.angle += 10
    
        root_node.accept(render)
        clock.tick(60)
        pygame.display.flip()
        world.foreground.angle += 0.01
        time += 1
        prog.update(time=time)
        
        
        
main()
