
import pygame
from pygame.locals import *

import qgl

def basic_screen(size):
    """
    Returns a root node with viewport and world children.
    """
    root_node = qgl.scene.Root()
    root_node.add(
        qgl.scene.PerspectiveViewport(
            qgl.scene.World()
        )
    )
    viewport = root_node[0]
    world = viewport[0]
    viewport.screen_dimensions = (0,0,size[0], size[1])
    viewport.aspect = float(size[0]) / size[1]
    return root_node, viewport, world

def main():
    pygame.init()
    flags =  OPENGL|DOUBLEBUF|HWSURFACE
    pygame.display.set_mode((800,600), flags)
    
    compiler = qgl.render.Compiler()
    render = qgl.render.Render()
    picker = qgl.render.Picker()
    
    clock = pygame.time.Clock()
    
    root_node, viewport, world = basic_screen((800,600))
    
    
    model = qgl.scene.Static(qgl.scene.Texture('r1station.jpg'), qgl.scene.Mesh("r1station.obj"))
    model.translate = (0,0,-20)
    world.background.add(model)
    
    
    root_node.accept(compiler)
    
    while True:
        for event in pygame.event.get():
            if event.type is QUIT:
                return
            elif event.type is KEYDOWN:
                print clock.get_fps()
                if event.key == 27: 
                    return
            elif event.type is MOUSEBUTTONDOWN:
                picker.set_position(event.pos)
                root_node.accept(picker)
                for hit in  picker.hits:
                    hit.angle += 10
        model.angle += 1
        root_node.accept(render)
        clock.tick()
        pygame.display.flip()
        
        
main()

